BalanceStrategy

Enum BalanceStrategy 

pub enum BalanceStrategy {
    None,
    Permute,
    Scale,
    Both,
}
Balancing strategy applied before the QZ factorization.

Balancing can improve the accuracy and convergence of the QZ algorithm by reducing the norm of off-diagonal elements through similarity transformations that preserve the eigenvalues.

Variants



None

No balancing — use the matrices as given.



Permute

Permute rows and columns to isolate eigenvalues if possible.



Scale

Scale rows and columns to make the norms more uniform.



Both

Both permute and scale (default for best accuracy).