MultifrontalLUSolver

Struct MultifrontalLUSolver 

pub struct MultifrontalLUSolver { /* private fields */ }
Multifrontal LU solver for general (non-symmetric) sparse systems.

Performs P * A = L * U factorization with partial pivoting within each frontal matrix, using the supernodal structure for efficient dense operations.

Implementations

Source

impl MultifrontalLUSolver

pub fn symbolic( row_offsets: &[usize], col_indices: &[usize], n: usize, ) -> Result<Self, SolverError>

Symbolic factorization.

pub fn numeric( &mut self, row_offsets: &[usize], col_indices: &[usize], values: &[f64], ) -> Result<(), SolverError>

Numeric factorization with partial pivoting.

Assembles the full matrix and performs LU decomposition with partial pivoting (GETRF-like).

pub fn solve(&self, rhs: &[f64]) -> Result<Vec<f64>, SolverError>

Solve A * x = b using the LU factorization.

Applies P * b, then forward solve L * y = P * b, then backward solve U * x = y.