Condition number estimation.
Provides routines for estimating the condition number of a matrix, which measures the sensitivity of the solution of a linear system to perturbations in the input data. Uses Hager’s algorithm (1-norm estimator) to avoid forming the inverse explicitly.
Enums
- Norm
Type - Norm type for condition number estimation.
Functions
- condition_
number_ estimate - Estimates the condition number of a matrix.